Module diff

Module diff 

Structs

CellDiff
A single changed cell.
Diff
Top-level diff result between two .xlsx workbooks.
SheetCellDiff
All cell-level diffs for a single worksheet.
SheetDiff
Records a sheet that was added or removed between the two workbooks.

Enums

CellDiffKind
Whether a cell diff concerns its displayed value or its formula.