Module unified_format

Module unified_format 

Structs

FormattedUnifiedDiff
Unified diff with prefix markers applied to each line.
SplitUnifiedDiff
Unified diff split into separate old and new views.
SplitUnifiedDiffContent
One sheet’s content in a split unified diff.
SplitUnifiedDiffLine
A single line in a split unified diff.
UnifiedDiff
Unified diff ready for further formatting or splitting.
UnifiedDiffContent
One sheet’s worth of unified diff content.
UnifiedDiffLine
A single line in a unified diff.

Functions

unified_diff
Builds a UnifiedDiff from the raw Diff result.