pub fn compare_bytes_with_options(
old: impl AsRef<[u8]>,
new: impl AsRef<[u8]>,
opts: DiffOptions,
) -> Result<WorkbookDiff, SheetsDiffError>Expand description
Compare two workbooks given byte slices, with explicit options.
pub fn compare_bytes_with_options(
old: impl AsRef<[u8]>,
new: impl AsRef<[u8]>,
opts: DiffOptions,
) -> Result<WorkbookDiff, SheetsDiffError>Compare two workbooks given byte slices, with explicit options.