pub fn compare_paths_with_options(
old: impl AsRef<Path>,
new: impl AsRef<Path>,
opts: DiffOptions,
) -> Result<WorkbookDiff, SheetsDiffError>Expand description
Compare two workbooks given their filesystem paths, with explicit options.
pub fn compare_paths_with_options(
old: impl AsRef<Path>,
new: impl AsRef<Path>,
opts: DiffOptions,
) -> Result<WorkbookDiff, SheetsDiffError>Compare two workbooks given their filesystem paths, with explicit options.