pub struct SourceDescription {
pub kind: SourceKind,
pub display_name: Option<String>,
}Expand description
Caller-visible description of a workbook input source.
display_name is never an absolute path unless the caller explicitly
provided it as such.
Fields
kind: SourceKinddisplay_name: Option<String>Trait Implementations
Sourceimpl Clone for SourceDescription
impl Clone for SourceDescription
Sourcefn clone(&self) -> SourceDescription
fn clone(&self) -> SourceDescription
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceDescription
impl Debug for SourceDescription
Sourceimpl PartialEq for SourceDescription
impl PartialEq for SourceDescription
Sourcefn eq(&self, other: &SourceDescription) -> bool
fn eq(&self, other: &SourceDescription) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SourceDescription