pub struct ChangeAnchor {
pub sheet_index: usize,
pub row: u32,
pub col: u32,
}Expand description
A stable, deterministic identifier for a single change row.
Ordering matches the canonical (sheet_index, row, col) sort.
Fields
sheet_index: usizerow: u32col: u32Trait Implementations
Sourceimpl Clone for ChangeAnchor
impl Clone for ChangeAnchor
Sourcefn clone(&self) -> ChangeAnchor
fn clone(&self) -> ChangeAnchor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChangeAnchor
impl Debug for ChangeAnchor
impl Eq for ChangeAnchor
Sourceimpl Ord for ChangeAnchor
impl Ord for ChangeAnchor
Sourcefn cmp(&self, other: &ChangeAnchor) -> Ordering
fn cmp(&self, other: &ChangeAnchor) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ChangeAnchor
impl PartialEq for ChangeAnchor
Sourcefn eq(&self, other: &ChangeAnchor) -> bool
fn eq(&self, other: &ChangeAnchor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ChangeAnchor
impl PartialOrd for ChangeAnchor
impl StructuralPartialEq for ChangeAnchor