pub struct ViewFilter {
pub include_values: bool,
pub include_formulas: bool,
pub include_formatting: bool,
pub include_info_diagnostics: bool,
pub sheets: Option<Vec<usize>>,
}Expand description
Controls which change categories are visible in a DiffView.
Fields
include_values: boolinclude_formulas: boolinclude_formatting: boolFormatting diffs (always false until RFC-022 is implemented).
include_info_diagnostics: boolsheets: Option<Vec<usize>>If Some, only include changes from the listed sheet indices (0-based).