#[non_exhaustive]pub struct WorkbookDiff {
pub old: WorkbookSideInfo,
pub new: WorkbookSideInfo,
pub sheets: Vec<SheetDiff>,
pub workbook_changes: Vec<WorkbookChange>,
pub object_changes: Vec<WorkbookObjectChange>,
pub diagnostics: Vec<Diagnostic>,
pub summary: DiffSummary,
}Expand description
The complete diff result for a workbook pair.
workbook_changes and object_changes are reserved for RFC-021/023 (v2.1+)
and are always empty in v2.0. Because the struct is #[non_exhaustive] and
read-only for application code, those fields can be populated additively.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.old: WorkbookSideInfonew: WorkbookSideInfosheets: Vec<SheetDiff>Sheet diffs in old-workbook sheet order (then new-workbook order for added sheets).
workbook_changes: Vec<WorkbookChange>Reserved; empty until RFC-021.
object_changes: Vec<WorkbookObjectChange>Reserved; empty until RFC-023.
diagnostics: Vec<Diagnostic>summary: DiffSummaryTrait Implementations
Sourceimpl Clone for WorkbookDiff
impl Clone for WorkbookDiff
Sourcefn clone(&self) -> WorkbookDiff
fn clone(&self) -> WorkbookDiff
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkbookDiff
impl Debug for WorkbookDiff
Sourceimpl PartialEq for WorkbookDiff
impl PartialEq for WorkbookDiff
Sourcefn eq(&self, other: &WorkbookDiff) -> bool
fn eq(&self, other: &WorkbookDiff) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for WorkbookDiff